@@ -21,15 +21,15 @@ class gPodderExtension:
     # into various parts of gPodder.
     def on_load(self):
         logger.info('Extension is being loaded.')
-        print '='*40
-        print 'container:', self.container
-        print 'container.manager:', self.container.manager
-        print 'container.config:', self.container.config
-        print 'container.manager.core:', self.container.manager.core
-        print 'container.manager.core.db:', self.container.manager.core.db
-        print 'container.manager.core.config:', self.container.manager.core.config
-        print 'container.manager.core.model:', self.container.manager.core.model
-        print '='*40
+        print('='*40)
+        print('container:', self.container)
+        print('container.manager:', self.container.manager)
+        print('container.config:', self.container.config)
+        print('container.manager.core:', self.container.manager.core)
+        print('container.manager.core.db:', self.container.manager.core.db)
+        print('container.manager.core.config:', self.container.manager.core.config)
+        print('container.manager.core.model:', self.container.manager.core.model)
+        print('='*40)
 
     # This function will be called when the extension is disabled or
     # when gPodder shuts down. You can use this to destroy/delete any
@@ -37,3 +37,16 @@ class gPodderExtension:
     def on_unload(self):
         logger.info('Extension is being unloaded.')
 
+
+    def on_ui_object_available(self, name, ui_object):
+        """
+        Called by gPodder when ui is ready
+        """
+        if name == 'gpodder-gtk':
+            self.gpodder = ui_object
+
+    def on_create_menu(self):
+        return [("Say Hello", self.say_hello_cb)]
+
+    def say_hello_cb(self):
+        self.gpodder.notification("Hello Extension", "Message", widget=self.gpodder.main_window)
