@@ -103,7 +103,7 @@ class AudioFile(object):
         None
 
     def get_cover_picture(self, cover):
-        """ Returns mutage Picture class for the cover image
+        """ Returns mutagen Picture class for the cover image
         Usefull for OGG and FLAC format
 
         Picture type = cover image
@@ -162,7 +162,7 @@ class Mp3File(AudioFile):
                 encoding = 3, # 3 is for utf-8
                 mime = mimetypes.guess_type(self.cover)[0],
                 type = 3,
-                desc = u'Cover',
+                desc = 'Cover',
                 data = open(self.cover).read()
             )
         )
@@ -183,32 +183,28 @@ class gPodderExtension:
     def get_audio(self, info, episode):
         audio = None
         cover = None
+        audioClass = None
 
         if self.container.config.auto_embed_coverart:
             cover = self.get_cover(episode.channel)
 
         if info['filename'].endswith('.mp3'):
-            audio = Mp3File(info['filename'],
-                info['album'],
-                info['title'],
-                info['genre'],
-                info['pubDate'],
-                cover)
+            audioClass = Mp3File
         elif info['filename'].endswith('.ogg'):
-            audio = OggFile(info['filename'],
-                info['album'],
-                info['title'],
-                info['genre'],
-                info['pubDate'],
-                cover)
+            audioClass = OggFile
         elif info['filename'].endswith('.m4a') or info['filename'].endswith('.mp4'):
-            audio = Mp4File(info['filename'],
+            audioClass = Mp4File
+        elif File(info['filename'], easy=True):
+            # mutagen can work with it: at least add basic tags
+            audioClass = AudioFile
+
+        if audioClass:
+            audio = audioClass(info['filename'],
                 info['album'],
                 info['title'],
                 info['genre'],
                 info['pubDate'],
                 cover)
-
         return audio
 
     def read_episode_info(self, episode):
@@ -261,7 +257,7 @@ class gPodderExtension:
             if self.container.config.auto_embed_coverart:
                 audio.insert_coverart()
 
-        logger.info(u'tagging.on_episode_downloaded(%s/%s)', episode.channel.title, episode.title)
+        logger.info('tagging.on_episode_downloaded(%s/%s)', episode.channel.title, episode.title)
 
     def get_cover(self, podcast):
         downloader = coverart.CoverDownloader()
