@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2017 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -68,7 +68,7 @@ def find_partial_downloads(channels, start_progress_callback, progress_callback,
                 filename = episode.local_filename(create=False, check_only=True)
                 if filename in candidates:
                     found += 1
-                    progress_callback(episode.title, float(found)/count)
+                    progress_callback(episode.title, found/count)
                     candidates.remove(filename)
                     partial_files.remove(filename+'.partial')
 
