@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2017 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -128,7 +128,6 @@ defaults = {
             },
 
             'toolbar': False,
-            'html_shownotes': True,
             'new_episodes': 'show', # ignore, show, queue, download
             'live_search_delay': 200,
 
@@ -148,6 +147,8 @@ defaults = {
             'download_list': {
                 'remove_finished': True,
             },
+
+            'html_shownotes': True,  # enable webkit renderer
         },
     },
 
@@ -211,7 +212,6 @@ gPodderSettings_LegacySupport = {
     'episode_list_descriptions': 'ui.gtk.episode_list.descriptions',
     'podcast_list_view_all': 'ui.gtk.podcast_list.all_episodes',
     'podcast_list_sections': 'ui.gtk.podcast_list.sections',
-    'enable_html_shownotes': 'ui.gtk.html_shownotes',
     'episode_list_view_mode': 'ui.gtk.episode_list.view_mode',
     'podcast_list_view_mode': 'ui.gtk.podcast_list.view_mode',
     'podcast_list_hide_boring': 'ui.gtk.podcast_list.hide_empty',
@@ -230,7 +230,7 @@ def config_value_to_string(config_value):
 
     if config_type == list:
         return ','.join(map(config_value_to_string, config_value))
-    elif config_type in (str, unicode):
+    elif config_type in (str, str):
         return config_value
     else:
         return str(config_value)
@@ -239,7 +239,7 @@ def string_to_config_value(new_value, old_value):
     config_type = type(old_value)
 
     if config_type == list:
-        return filter(None, [x.strip() for x in new_value.split(',')])
+        return [_f for _f in [x.strip() for x in new_value.split(',')] if _f]
     elif config_type == bool:
         return (new_value.strip().lower() in ('1', 'true'))
     else:
@@ -368,7 +368,7 @@ class Config(object):
         for observer in self.__observers:
             try:
                 observer(name, old_value, value)
-            except Exception, exception:
+            except Exception as exception:
                 logger.error('Error while calling observer %r: %s',
                         observer, exception, exc_info=True)
 
