@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2017 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,16 +29,18 @@ from gpodder import util
 import logging
 logger = logging.getLogger(__name__)
 
-from urllib2 import HTTPError
-from HTMLParser import HTMLParser
-import urlparse
+from urllib.error import HTTPError
+from html.parser import HTMLParser
+import urllib.parse
 
 try:
     # Python 2
     from rfc822 import mktime_tz
+    from StringIO import StringIO
 except ImportError:
     # Python 3
     from email.utils import mktime_tz
+    from io import StringIO
 
 
 class ExceptionWithData(Exception):
@@ -65,7 +67,7 @@ class UnknownStatusCode(ExceptionWithData): pass
 class AuthenticationRequired(Exception): pass
 
 # Successful status codes
-UPDATED_FEED, NEW_LOCATION, NOT_MODIFIED, CUSTOM_FEED = range(4)
+UPDATED_FEED, NEW_LOCATION, NOT_MODIFIED, CUSTOM_FEED = list(range(4))
 
 class Result:
     def __init__(self, status, feed=None):
@@ -86,7 +88,7 @@ class FeedAutodiscovery(HTMLParser):
             is_feed = attrs.get('type', '') in Fetcher.FEED_TYPES
             is_alternate = attrs.get('rel', '') == 'alternate'
             url = attrs.get('href', None)
-            url = urlparse.urljoin(self._base, url)
+            url = urllib.parse.urljoin(self._base, url)
 
             if is_feed and is_alternate and url:
                 logger.info('Feed autodiscovery: %s', url)
@@ -171,27 +173,45 @@ class Fetcher(object):
             except HTTPError as e:
                 return self._check_statuscode(e, e.geturl())
 
-        if stream.headers.get('content-type', '').startswith('text/html'):
-            if autodiscovery:
-                ad = FeedAutodiscovery(url)
-                ad.feed(stream.read())
-                if ad._resolved_url:
-                    try:
-                        self._parse_feed(ad._resolved_url, None, None, False)
-                        return Result(NEW_LOCATION, ad._resolved_url)
-                    except Exception as e:
-                        logger.warn('Feed autodiscovery failed', exc_info=True)
+        data = stream
+        if autodiscovery and not is_local and stream.headers.get('content-type', '').startswith('text/html'):
+            # Not very robust attempt to detect encoding: http://stackoverflow.com/a/1495675/1072626
+            charset = stream.headers.get_param('charset')
+            if charset is None:
+                charset = 'utf-8' # utf-8 appears hard-coded elsewhere in this codebase
 
-                    # Second, try to resolve the URL
-                    url = self._resolve_url(url)
-                    if url:
-                        return Result(NEW_LOCATION, url)
+            # We use StringIO in case the stream needs to be read again
+            data = StringIO(stream.read().decode(charset))
+            ad = FeedAutodiscovery(url)
 
-            raise InvalidFeed('Got HTML document instead')
+            ad.feed(data.getvalue())
+            if ad._resolved_url:
+                try:
+                    self._parse_feed(ad._resolved_url, None, None, False)
+                    return Result(NEW_LOCATION, ad._resolved_url)
+                except Exception as e:
+                    logger.warn('Feed autodiscovery failed', exc_info=True)
 
-        feed = podcastparser.parse(url, stream)
-        feed['headers'] = stream.headers
-        return self._check_statuscode(stream, feed)
+                # Second, try to resolve the URL
+                url = self._resolve_url(url)
+                if url:
+                    return Result(NEW_LOCATION, url)
+
+            # Reset the stream so podcastparser can give it a go
+            data.seek(0)
+
+
+        try:
+            feed = podcastparser.parse(url, data)
+        except ValueError as e:
+            raise InvalidFeed('Could not parse feed: {msg}'.format(msg=e))
+
+        if is_local:
+            feed['headers'] = {}
+            return Result(UPDATED_FEED, feed)
+        else:
+            feed['headers'] = stream.headers
+            return self._check_statuscode(stream, feed)
 
     def fetch(self, url, etag=None, modified=None):
         return self._parse_feed(url, etag, modified)
