@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2017 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,11 +30,11 @@ import os
 import os.path
 import threading
 
-from ConfigParser import RawConfigParser
+from configparser import RawConfigParser
 
-import gobject
-import gtk
-import gtk.gdk
+from gi.repository import GObject
+from gi.repository import GdkPixbuf
+from gi.repository import Gtk
 
 import gpodder
 
@@ -49,11 +49,11 @@ userappsdirs = [ '/usr/share/applications/', '/usr/local/share/applications/', '
 # the name of the section in the .desktop files
 sect = 'Desktop Entry'
 
-class PlayerListModel(gtk.ListStore):
-    C_ICON, C_NAME, C_COMMAND, C_CUSTOM = range(4)
+class PlayerListModel(Gtk.ListStore):
+    C_ICON, C_NAME, C_COMMAND, C_CUSTOM = list(range(4))
 
     def __init__(self):
-        gtk.ListStore.__init__(self, gtk.gdk.Pixbuf, str, str, bool)
+        Gtk.ListStore.__init__(self, GdkPixbuf.Pixbuf, str, str, bool)
 
     def insert_app(self, pixbuf, name, command):
         self.append((pixbuf, name, command, False))
@@ -92,13 +92,13 @@ class UserApplication(object):
             # Load it from an absolute filename
             if os.path.exists(self.icon):
                 try:
-                    return gtk.gdk.pixbuf_new_from_file_at_size(self.icon, 24, 24)
-                except gobject.GError, ge:
+                    return GdkPixbuf.Pixbuf.new_from_file_at_size(self.icon, 24, 24)
+                except GObject.GError as ge:
                     pass
 
             # Load it from the current icon theme
             (icon_name, extension) = os.path.splitext(os.path.basename(self.icon))
-            theme = gtk.IconTheme()
+            theme = Gtk.IconTheme()
             if theme.has_icon(icon_name):
                 return theme.load_icon(icon_name, 24, 0)
 
@@ -116,23 +116,23 @@ WIN32_APP_REG_KEYS = [
 
 
 def win32_read_registry_key(path):
-    import _winreg
+    import winreg
 
     rootmap = {
-        'HKEY_CLASSES_ROOT': _winreg.HKEY_CLASSES_ROOT,
+        'HKEY_CLASSES_ROOT': winreg.HKEY_CLASSES_ROOT,
     }
 
     parts = path.split('\\')
     root = parts.pop(0)
-    key = _winreg.OpenKey(rootmap[root], parts.pop(0))
+    key = winreg.OpenKey(rootmap[root], parts.pop(0))
 
     while parts:
-        key = _winreg.OpenKey(key, parts.pop(0))
+        key = winreg.OpenKey(key, parts.pop(0))
 
-    value, type_ = _winreg.QueryValueEx(key, '')
-    if type_ == _winreg.REG_EXPAND_SZ:
+    value, type_ = winreg.QueryValueEx(key, '')
+    if type_ == winreg.REG_EXPAND_SZ:
         cmdline = re.sub(r'%([^%]+)%', lambda m: os.environ[m.group(1)], value)
-    elif type_ == _winreg.REG_SZ:
+    elif type_ == winreg.REG_SZ:
         cmdline = value
     else:
         raise ValueError('Not a string: ' + path)
@@ -151,7 +151,7 @@ class UserAppsReader(object):
         self.__has_read = False
         self.__finished = threading.Event()
         self.__has_sep = False
-        self.apps.append(UserApplication(_('Default application'), 'default', ';'.join((mime+'/*' for mime in self.mimetypes)), gtk.STOCK_OPEN))
+        self.apps.append(UserApplication(_('Default application'), 'default', ';'.join((mime+'/*' for mime in self.mimetypes)), Gtk.STOCK_OPEN))
 
     def add_separator(self):
         self.apps.append(UserApplication('', '', ';'.join((mime+'/*' for mime in self.mimetypes)), ''))
@@ -163,7 +163,7 @@ class UserAppsReader(object):
 
         self.__has_read = True
         if gpodder.ui.win32:
-            import _winreg
+            import winreg
             for caption, types, hkey in WIN32_APP_REG_KEYS:
                 try:
                     cmdline = win32_read_registry_key(hkey)
