@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2017 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,11 +25,18 @@
 
 import gpodder
 
-import gtk
-import pango
-import pangocairo
+import gi
+gi.require_version('PangoCairo', '1.0')
+
+from gi.repository import Gtk
+from gi.repository import Gdk
+from gi.repository import GdkPixbuf
+from gi.repository import Pango
+from gi.repository import PangoCairo
+
 import cairo
-import StringIO
+
+import io
 import math
 
 
@@ -87,25 +94,25 @@ def rounded_rectangle(ctx, x, y, width, height, radius=4.):
 
 
 def draw_text_box_centered(ctx, widget, w_width, w_height, text, font_desc=None, add_progress=None):
-    style = widget.rc_get_style()
-    text_color = style.text[gtk.STATE_PRELIGHT]
+    style_context = widget.get_style_context()
+    text_color = style_context.get_color(Gtk.StateFlags.PRELIGHT)
     red, green, blue = text_color.red, text_color.green, text_color.blue
-    text_color = [float(x)/65535. for x in (red, green, blue)]
+    text_color = [x/65535. for x in (red, green, blue)]
     text_color.append(.5)
 
     if font_desc is None:
-        font_desc = style.font_desc
-        font_desc.set_size(14*pango.SCALE)
+        font_desc = style_context.get_font(Gtk.StateFlags.NORMAL)
+        font_desc.set_size(14*Pango.SCALE)
 
     pango_context = widget.create_pango_context()
-    layout = pango.Layout(pango_context)
+    layout = Pango.Layout(pango_context)
     layout.set_font_description(font_desc)
-    layout.set_text(text)
+    layout.set_text(text, -1)
     width, height = layout.get_pixel_size()
 
     ctx.move_to(w_width/2-width/2, w_height/2-height/2)
     ctx.set_source_rgba(*text_color)
-    ctx.show_layout(layout)
+    PangoCairo.show_layout(ctx, layout)
 
     # Draw an optional progress bar below the text (same width)
     if add_progress is not None:
@@ -126,13 +133,17 @@ def draw_cake(percentage, text=None, emblem=None, size=None):
         size = EPISODE_LIST_ICON_SIZE
 
     surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, size, size)
-    ctx = pangocairo.CairoContext(cairo.Context(surface))
+    ctx = cairo.Context(surface)
 
-    widget = gtk.ProgressBar()
-    style = widget.rc_get_style()
-    bgc = style.bg[gtk.STATE_NORMAL]
-    fgc = style.bg[gtk.STATE_SELECTED]
-    txc = style.text[gtk.STATE_NORMAL]
+    # ELL: get all black
+    #widget = Gtk.ProgressBar()
+    #style_context = widget.get_style_context()
+    bgc = Gdk.RGBA() #style_context.get_background_color(Gtk.StateFlags.NORMAL)
+    bgc.parse('white')
+    fgc = Gdk.RGBA() #style_context.get_background_color(Gtk.StateFlags.SELECTED)
+    fgc.parse('#4a90d9')
+    txc = Gdk.RGBA() #style_context.get_color(Gtk.StateFlags.NORMAL)
+    txc.parse('#333333')
 
     border = 1.5
     height = int(size*.4)
@@ -142,19 +153,19 @@ def draw_cake(percentage, text=None, emblem=None, size=None):
 
     # Background
     ctx.rectangle(x, y, width, height)
-    ctx.set_source_rgb(bgc.red_float, bgc.green_float, bgc.blue_float)
+    ctx.set_source_rgb(bgc.red, bgc.green, bgc.blue)
     ctx.fill()
 
     # Filling
     if percentage > 0:
         fill_width = max(1, min(width-2, (width-2)*percentage+.5))
         ctx.rectangle(x+1, y+1, fill_width, height-2)
-        ctx.set_source_rgb(fgc.red_float, fgc.green_float, fgc.blue_float)
+        ctx.set_source_rgb(0.289, 0.5625, 0.84765625)
         ctx.fill()
 
     # Border
     ctx.rectangle(x, y, width, height)
-    ctx.set_source_rgb(txc.red_float, txc.green_float, txc.blue_float)
+    ctx.set_source_rgb(txc.red, txc.green, txc.blue)
     ctx.set_line_width(1)
     ctx.stroke()
 
@@ -162,12 +173,10 @@ def draw_cake(percentage, text=None, emblem=None, size=None):
     return surface
 
 def draw_text_pill(left_text, right_text, x=0, y=0, border=2, radius=14, font_desc=None):
-    # Create temporary context to calculate the text size
-    ctx = cairo.Context(cairo.ImageSurface(cairo.FORMAT_ARGB32, 1, 1))
 
     # Use GTK+ style of a normal Button
-    widget = gtk.Label()
-    style = widget.rc_get_style()
+    widget = Gtk.Label()
+    style_context = widget.get_style_context()
 
     # Padding (in px) at the right edge of the image (for Ubuntu; bug 1533)
     padding_right = 7
@@ -175,16 +184,16 @@ def draw_text_pill(left_text, right_text, x=0, y=0, border=2, radius=14, font_de
     x_border = border*2
 
     if font_desc is None:
-        font_desc = style.font_desc
-        font_desc.set_weight(pango.WEIGHT_BOLD)
+        font_desc = style_context.get_font(Gtk.StateFlags.NORMAL)
+        font_desc.set_weight(Pango.Weight.BOLD)
 
     pango_context = widget.create_pango_context()
-    layout_left = pango.Layout(pango_context)
+    layout_left = Pango.Layout(pango_context)
     layout_left.set_font_description(font_desc)
-    layout_left.set_text(left_text)
-    layout_right = pango.Layout(pango_context)
+    layout_left.set_text(left_text, -1)
+    layout_right = Pango.Layout(pango_context)
     layout_right.set_font_description(font_desc)
-    layout_right.set_text(right_text)
+    layout_right.set_text(right_text, -1)
 
     width_left, height_left = layout_left.get_pixel_size()
     width_right, height_right = layout_right.get_pixel_size()
@@ -193,9 +202,9 @@ def draw_text_pill(left_text, right_text, x=0, y=0, border=2, radius=14, font_de
 
     image_height = int(y+text_height+border*2)
     image_width = int(x+width_left+width_right+x_border*4+padding_right)
-    surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, image_width, image_height)
 
-    ctx = pangocairo.CairoContext(cairo.Context(surface))
+    surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, image_width, image_height)
+    ctx = cairo.Context(surface)
 
     # Clip so as to not draw on the right padding (for Ubuntu; bug 1533)
     ctx.rectangle(0, 0, image_width - padding_right, image_height)
@@ -235,39 +244,39 @@ def draw_text_pill(left_text, right_text, x=0, y=0, border=2, radius=14, font_de
 
         ctx.move_to(x+x_border, y+1+border)
         ctx.set_source_rgba( 0, 0, 0, 1)
-        ctx.show_layout(layout_left)
+        PangoCairo.show_layout(ctx, layout_left)
         ctx.move_to(x-1+x_border, y+border)
         ctx.set_source_rgba( 1, 1, 1, 1)
-        ctx.show_layout(layout_left)
+        PangoCairo.show_layout(ctx, layout_left)
 
     if right_text is not None:
-        draw_rounded_rectangle(ctx, x, y, rect_width, rect_height, radius, left_side_width, RRECT_RIGHT_SIDE, left_text is None)
-        linear = cairo.LinearGradient(x+left_side_width, y, x+left_side_width+right_side_width/2, y+rect_height)
-        linear.add_color_stop_rgba(0, .2, .2, .2, .9)
-        linear.add_color_stop_rgba(.4, .2, .2, .2, .8)
-        linear.add_color_stop_rgba(.6, .2, .2, .2, .6)
-        linear.add_color_stop_rgba(.9, .2, .2, .2, .7)
-        linear.add_color_stop_rgba(1, .2, .2, .2, .5)
-        ctx.set_source(linear)
-        ctx.fill()
-        xpos, ypos, width, height = x, y+1, rect_width-1, rect_height-2
-        if left_text is None:
-            xpos, width = x+1, rect_width-2
-        draw_rounded_rectangle(ctx, xpos, ypos, width, height, radius, left_side_width, RRECT_RIGHT_SIDE, left_text is None)
-        ctx.set_source_rgba(1., 1., 1., .3)
-        ctx.set_line_width(1)
-        ctx.stroke()
-        draw_rounded_rectangle(ctx, x, y, rect_width, rect_height, radius, left_side_width, RRECT_RIGHT_SIDE, left_text is None)
-        ctx.set_source_rgba(.1, .1, .1, .6)
-        ctx.set_line_width(1)
-        ctx.stroke()
+       draw_rounded_rectangle(ctx, x, y, rect_width, rect_height, radius, left_side_width, RRECT_RIGHT_SIDE, left_text is None)
+       linear = cairo.LinearGradient(x+left_side_width, y, x+left_side_width+right_side_width/2, y+rect_height)
+       linear.add_color_stop_rgba(0, .2, .2, .2, .9)
+       linear.add_color_stop_rgba(.4, .2, .2, .2, .8)
+       linear.add_color_stop_rgba(.6, .2, .2, .2, .6)
+       linear.add_color_stop_rgba(.9, .2, .2, .2, .7)
+       linear.add_color_stop_rgba(1, .2, .2, .2, .5)
+       ctx.set_source(linear)
+       ctx.fill()
+       xpos, ypos, width, height = x, y+1, rect_width-1, rect_height-2
+       if left_text is None:
+           xpos, width = x+1, rect_width-2
+       draw_rounded_rectangle(ctx, xpos, ypos, width, height, radius, left_side_width, RRECT_RIGHT_SIDE, left_text is None)
+       ctx.set_source_rgba(1., 1., 1., .3)
+       ctx.set_line_width(1)
+       ctx.stroke()
+       draw_rounded_rectangle(ctx, x, y, rect_width, rect_height, radius, left_side_width, RRECT_RIGHT_SIDE, left_text is None)
+       ctx.set_source_rgba(.1, .1, .1, .6)
+       ctx.set_line_width(1)
+       ctx.stroke()
 
-        ctx.move_to(x+left_side_width+x_border, y+1+border)
-        ctx.set_source_rgba( 0, 0, 0, 1)
-        ctx.show_layout(layout_right)
-        ctx.move_to(x-1+left_side_width+x_border, y+border)
-        ctx.set_source_rgba( 1, 1, 1, 1)
-        ctx.show_layout(layout_right)
+       ctx.move_to(x+left_side_width+x_border, y+1+border)
+       ctx.set_source_rgba( 0, 0, 0, 1)
+       PangoCairo.show_layout(ctx, layout_right)
+       ctx.move_to(x-1+left_side_width+x_border, y+border)
+       ctx.set_source_rgba( 1, 1, 1, 1)
+       PangoCairo.show_layout(ctx, layout_right)
 
     return surface
 
@@ -284,19 +293,19 @@ def cairo_surface_to_pixbuf(s):
     Converts a Cairo surface to a Gtk Pixbuf by
     encoding it as PNG and using the PixbufLoader.
     """
-    sio = StringIO.StringIO()
+    bio = io.BytesIO()
     try:
-        s.write_to_png(sio)
+        s.write_to_png(bio)
     except:
         # Write an empty PNG file to the StringIO, so
         # in case of an error we have "something" to
         # load. This happens in PyCairo < 1.1.6, see:
         # http://webcvs.cairographics.org/pycairo/NEWS?view=markup
         # Thanks to Chris Arnold for reporting this bug
-        sio.write('iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A\n/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB9cMEQkqIyxn3RkAAAAZdEVYdENv\nbW1lbnQAQ3JlYXRlZCB3aXRoIEdJTVBXgQ4XAAAADUlEQVQI12NgYGBgAAAABQABXvMqOgAAAABJ\nRU5ErkJggg==\n'.decode('base64'))
+        bio.write('iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A\n/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB9cMEQkqIyxn3RkAAAAZdEVYdENv\nbW1lbnQAQ3JlYXRlZCB3aXRoIEdJTVBXgQ4XAAAADUlEQVQI12NgYGBgAAAABQABXvMqOgAAAABJ\nRU5ErkJggg==\n'.decode('base64'))
 
-    pbl = gtk.gdk.PixbufLoader()
-    pbl.write(sio.getvalue())
+    pbl = GdkPixbuf.PixbufLoader()
+    pbl.write(bio.getvalue())
     pbl.close()
 
     pixbuf = pbl.get_pixbuf()
@@ -312,7 +321,7 @@ def progressbar_pixbuf(width, height, percentage):
     surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, width, height)
     ctx = cairo.Context(surface)
 
-    padding = int(float(width)/8.0)
+    padding = int(width/8.0)
     bar_width = 2*padding
     bar_height = height - 2*padding
     bar_height_fill = bar_height*percentage
@@ -337,4 +346,3 @@ def progressbar_pixbuf(width, height, percentage):
     ctx.stroke()
 
     return cairo_surface_to_pixbuf(surface)
-
