@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2017 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-import gtk
+from gi.repository import Gtk
+from gi.repository import Gdk
 
 import gpodder
 
@@ -43,8 +44,11 @@ class gPodderAddPodcast(BuilderWidget):
 
         if not hasattr(self, 'preset_url'):
             # Fill the entry if a valid URL is in the clipboard, but
-            # only if there's no preset_url available (see bug 1132)
-            clipboard = gtk.Clipboard(selection='PRIMARY')
+            # only if there's no preset_url available (see bug 1132).
+            # First try from CLIPBOARD (everyday copy-paste),
+            # then from SELECTION (text selected and pasted via
+            # middle mouse button).
+            clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
             def receive_clipboard_text(clipboard, text, second_try):
                 # Heuristic: If there is a space in the clipboard
                 # text, assume it's some arbitrary text, and no URL
@@ -56,7 +60,7 @@ class gPodderAddPodcast(BuilderWidget):
                         return
 
                 if not second_try:
-                    clipboard = gtk.Clipboard()
+                    clipboard = Gtk.Clipboard.get(Gdk.SELECTION_PRIMARY)
                     clipboard.request_text(receive_clipboard_text, True)
             clipboard.request_text(receive_clipboard_text, False)
 
@@ -64,7 +68,7 @@ class gPodderAddPodcast(BuilderWidget):
         self.gPodderAddPodcast.destroy()
 
     def on_btn_paste_clicked(self, widget):
-        clipboard = gtk.Clipboard()
+        clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
         clipboard.request_text(self.receive_clipboard_text)
 
     def receive_clipboard_text(self, clipboard, text, data=None):
