@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2017 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-import gtk
+from gi.repository import Gtk
 import cgi
 
 import gpodder
@@ -31,28 +31,30 @@ from gpodder.gtkui.interface.common import BuilderWidget
 
 class gPodderConfigEditor(BuilderWidget):
     def new(self):
-        name_column = gtk.TreeViewColumn(_('Setting'))
-        name_renderer = gtk.CellRendererText()
-        name_column.pack_start(name_renderer)
+        name_column = Gtk.TreeViewColumn(_('Setting'))
+        name_renderer = Gtk.CellRendererText()
+        name_column.pack_start(name_renderer, True)
         name_column.add_attribute(name_renderer, 'text', 0)
         name_column.add_attribute(name_renderer, 'style', 5)
+        name_column.set_expand(True)
         self.configeditor.append_column(name_column)
 
-        value_column = gtk.TreeViewColumn(_('Set to'))
-        value_check_renderer = gtk.CellRendererToggle()
-        value_column.pack_start(value_check_renderer, expand=False)
+        value_column = Gtk.TreeViewColumn(_('Set to'))
+        value_check_renderer = Gtk.CellRendererToggle()
+        value_column.pack_start(value_check_renderer, False)
         value_column.add_attribute(value_check_renderer, 'active', 7)
         value_column.add_attribute(value_check_renderer, 'visible', 6)
         value_column.add_attribute(value_check_renderer, 'activatable', 6)
         value_check_renderer.connect('toggled', self.value_toggled)
 
-        value_renderer = gtk.CellRendererText()
-        value_column.pack_start(value_renderer)
+        value_renderer = Gtk.CellRendererText()
+        value_column.pack_start(value_renderer, True)
         value_column.add_attribute(value_renderer, 'text', 2)
         value_column.add_attribute(value_renderer, 'visible', 4)
         value_column.add_attribute(value_renderer, 'editable', 4)
         value_column.add_attribute(value_renderer, 'style', 5)
         value_renderer.connect('edited', self.value_edited)
+        value_column.set_expand(False)
         self.configeditor.append_column(value_column)
 
         self.model = ConfigModel(self._config)
