@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2017 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,7 +34,8 @@ logger = logging.getLogger(__name__)
 from gpodder import util
 from gpodder import coverart
 
-import gtk
+from gi.repository import Gtk
+from gi.repository import GdkPixbuf
 
 
 class CoverDownloader(ObservableService):
@@ -117,14 +118,18 @@ class CoverDownloader(ObservableService):
         pixbuf = None
 
         try:
-            pixbuf = gtk.gdk.pixbuf_new_from_file(filename)
-        except Exception, e:
+            pixbuf = GdkPixbuf.Pixbuf.new_from_file(filename)
+        except Exception as e:
             logger.warn('Cannot load cover art', exc_info=True)
-            if filename.startswith(channel.cover_file):
-                logger.info('Deleting broken cover: %s', filename)
+        if pixbuf is None and filename.startswith(channel.cover_file):
+            logger.info('Deleting broken cover: %s', filename)
+            util.delete_file(filename)
+            filename = get_filename()
+            try:
+                pixbuf = GdkPixbuf.Pixbuf.new_from_file(filename)
+            except Exception as e:
+                logger.warn('Corrupt cover art on server, deleting', exc_info=True)
                 util.delete_file(filename)
-                filename = get_filename()
-                pixbuf = gtk.gdk.pixbuf_new_from_file(filename)
 
         if async:
             self.notify('cover-available', channel, pixbuf)
