@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2017 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,13 +24,9 @@
 #
 
 import copy
+from functools import reduce
 
-try:
-    # For Python < 2.6, we use the "simplejson" add-on module
-    import simplejson as json
-except ImportError:
-    # Python 2.6 already ships with a nice "json" module
-    import json
+import json
 
 
 class JsonConfigSubtree(object):
@@ -89,7 +85,7 @@ class JsonConfig(object):
         For newly-set keys, on_key_changed is also called. In this case,
         None will be the old_value:
 
-        >>> def callback(*args): print 'callback:', args
+        >>> def callback(*args): print('callback:', args)
         >>> c = JsonConfig(on_key_changed=callback)
         >>> c.a.b = 10
         callback: ('a.b', None, 10)
@@ -102,7 +98,7 @@ class JsonConfig(object):
 
         Please note that dict-style access will not call on_key_changed:
 
-        >>> def callback(*args): print 'callback:', args
+        >>> def callback(*args): print('callback:', args)
         >>> c = JsonConfig(on_key_changed=callback)
         >>> c.a.b = 1        # This works as expected
         callback: ('a.b', None, 1)
@@ -129,14 +125,14 @@ class JsonConfig(object):
         >>> c = JsonConfig()
         >>> c.a.b = 10
         >>> backup = repr(c)
-        >>> print c.a.b
+        >>> print(c.a.b)
         10
         >>> c.a.b = 11
-        >>> print c.a.b
+        >>> print(c.a.b)
         11
         >>> c._restore(backup)
         False
-        >>> print c.a.b
+        >>> print(c.a.b)
         10
         """
         self._data = json.loads(backup)
@@ -156,7 +152,7 @@ class JsonConfig(object):
         work_queue = [(self._data, merge_source)]
         while work_queue:
             data, default = work_queue.pop()
-            for key, value in default.iteritems():
+            for key, value in default.items():
                 if key not in data:
                     # Copy defaults for missing key
                     data[key] = copy.deepcopy(value)
@@ -175,7 +171,7 @@ class JsonConfig(object):
     def __repr__(self):
         """
         >>> c = JsonConfig('{"a": 1}')
-        >>> print c
+        >>> print(c)
         {
           "a": 1
         }
