@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2017 Thomas Perl and the gPodder Team
 # Copyright (c) 2011 Neal H. Walfield
 #
 # gPodder is free software; you can redistribute it and/or modify
@@ -112,7 +112,7 @@ class PodcastModelObject(object):
         o = cls(*args)
 
         # XXX: all(map(lambda k: hasattr(o, k), d))?
-        for k, v in d.iteritems():
+        for k, v in d.items():
             setattr(o, k, v)
 
         return o
@@ -145,6 +145,13 @@ class PodcastEpisode(PodcastModelObject):
         episode.title = entry['title']
         episode.link = entry['link']
         episode.description = entry['description']
+        if entry.get('description_html'):
+            episode.description_html = entry['description_html']
+        # TODO: This really should be handled in podcastparser and not here.
+        elif util.is_html(entry['description']):
+            episode.description_html = entry['description']
+            episode.description = util.remove_html_tags(entry['description'])
+
         episode.total_time = entry['total_time']
         episode.published = entry['published']
         episode.payment_url = entry['payment_url']
@@ -202,6 +209,7 @@ class PodcastEpisode(PodcastModelObject):
         self.mime_type = 'application/octet-stream'
         self.guid = ''
         self.description = ''
+        self.description_html = ''
         self.link = ''
         self.published = 0
         self.download_filename = None
@@ -333,14 +341,6 @@ class PodcastEpisode(PodcastModelObject):
 
     age_prop = property(fget=get_age_string)
 
-    @property
-    def description_html(self):
-        # XXX: That's not a very well-informed heuristic to check
-        # if the description already contains HTML. Better ideas?
-        if '<' in self.description:
-            return self.description
-
-        return self.description.replace('\n', '<br>')
 
     def one_line_description(self):
         MAX_LINE_LENGTH = 120
@@ -433,7 +433,7 @@ class PodcastEpisode(PodcastModelObject):
         if self.download_filename is None and (check_only or not create):
             return None
 
-        ext = self.extension(may_call_local_filename=False).encode('utf-8', 'ignore')
+        ext = self.extension(may_call_local_filename=False)
 
         if not check_only and (force_update or not self.download_filename):
             # Avoid and catch gPodder bug 1440 and similar situations
@@ -500,8 +500,7 @@ class PodcastEpisode(PodcastModelObject):
             self.download_filename = wanted_filename
             self.save()
 
-        return os.path.join(util.sanitize_encoding(self.channel.save_dir),
-                util.sanitize_encoding(self.download_filename))
+        return os.path.join(self.channel.save_dir, self.download_filename)
 
     def extension(self, may_call_local_filename=True):
         filename, ext = util.filename_from_url(self.url)
@@ -633,17 +632,17 @@ class PodcastEpisode(PodcastModelObject):
             return '-'
 
     def update_from(self, episode):
-        for k in ('title', 'url', 'description', 'link', 'published', 'guid', 'file_size', 'payment_url'):
+        for k in ('title', 'url', 'description', 'description_html', 'link', 'published', 'guid', 'file_size', 'payment_url'):
             setattr(self, k, getattr(episode, k))
 
 
 class PodcastChannel(PodcastModelObject):
     __slots__ = schema.PodcastColumns + ('_common_prefix',)
 
-    UNICODE_TRANSLATE = {ord(u'ö'): u'o', ord(u'ä'): u'a', ord(u'ü'): u'u'}
+    UNICODE_TRANSLATE = {ord('ö'): 'o', ord('ä'): 'a', ord('ü'): 'u'}
 
     # Enumerations for download strategy
-    STRATEGY_DEFAULT, STRATEGY_LATEST = range(2)
+    STRATEGY_DEFAULT, STRATEGY_LATEST = list(range(2))
 
     # Description and ordering of strategies
     STRATEGIES = [
@@ -812,12 +811,8 @@ class PodcastChannel(PodcastModelObject):
         return re.sub('^the ', '', key).translate(cls.UNICODE_TRANSLATE)
 
     @classmethod
-    def load(cls, model, url, create=True, authentication_tokens=None,\
-            max_episodes=0):
-        if isinstance(url, unicode):
-            url = url.encode('utf-8')
-
-        existing = filter(lambda p: p.url == url, model.get_podcasts())
+    def load(cls, model, url, create=True, authentication_tokens=None, max_episodes=0):
+        existing = [p for p in model.get_podcasts() if p.url == url]
 
         if existing:
             return existing[0]
@@ -835,7 +830,7 @@ class PodcastChannel(PodcastModelObject):
 
             try:
                 tmp.update(max_episodes)
-            except Exception, e:
+            except Exception as e:
                 logger.debug('Fetch failed. Removing buggy feed.')
                 tmp.remove_downloaded()
                 tmp.delete()
@@ -1034,7 +1029,7 @@ class PodcastChannel(PodcastModelObject):
                 pass
 
             self.save()
-        except Exception, e:
+        except Exception as e:
             # "Not really" errors
             #feedcore.AuthenticationRequired
             # Temporary errors
@@ -1153,7 +1148,7 @@ class PodcastChannel(PodcastModelObject):
         return self.children
 
     def get_episodes(self, state):
-        return filter(lambda e: e.state == state, self.get_all_episodes())
+        return [e for e in self.get_all_episodes() if e.state == state]
 
     def find_unique_folder_name(self, download_folder):
         # Remove trailing dots to avoid errors on Windows (bug 600)
@@ -1191,9 +1186,6 @@ class PodcastChannel(PodcastModelObject):
 
         save_dir = os.path.join(gpodder.downloads, self.download_folder)
 
-        # Avoid encoding errors for OS-specific functions (bug 1570)
-        save_dir = util.sanitize_encoding(save_dir)
-
         # Create save_dir if it does not yet exist
         if not util.make_directory(save_dir):
             logger.error('Could not create save_dir: %s', save_dir)
