@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2017 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,25 +28,24 @@ _ = gpodder.gettext
 from gpodder import model
 from gpodder import util
 
-try:
-    # For Python < 2.6, we use the "simplejson" add-on module
-    import simplejson as json
-except ImportError:
-    # Python 2.6 already ships with a nice "json" module
-    import json
+import json
 
+import logging
 import os
 import time
 
 import re
 import email
-import urllib
+import urllib.request, urllib.parse, urllib.error
 
 
 # gPodder's consumer key for the Soundcloud API
 CONSUMER_KEY = 'zrweghtEtnZLpXf3mlm8mQ'
 
 
+logger = logging.getLogger(__name__)
+
+
 def soundcloud_parsedate(s):
     """Parse a string into a unix timestamp
 
@@ -54,7 +53,7 @@ def soundcloud_parsedate(s):
     parsed with this function (2009/11/03 13:37:00).
     """
     m = re.match(r'(\d{4})/(\d{2})/(\d{2}) (\d{2}):(\d{2}):(\d{2})', s)
-    return time.mktime([int(x) for x in m.groups()]+[0, 0, -1])
+    return time.mktime(tuple([int(x) for x in m.groups()]+[0, 0, -1]))
 
 def get_param(s, param='filename', header='content-disposition'):
     """Get a parameter from a string of headers
@@ -72,8 +71,8 @@ def get_param(s, param='filename', header='content-disposition'):
             if encoding:
                 value.append(part.decode(encoding))
             else:
-                value.append(unicode(part))
-        return u''.join(value)
+                value.append(str(part))
+        return ''.join(value)
 
     return None
 
@@ -88,7 +87,7 @@ def get_metadata(url):
     headers = track_fp.info()
     filesize = headers['content-length'] or '0'
     filetype = headers['content-type'] or 'application/octet-stream'
-    headers_s = '\n'.join('%s:%s'%(k,v) for k, v in headers.items())
+    headers_s = '\n'.join('%s:%s'%(k,v) for k, v in list(headers.items()))
     filename = get_param(headers_s) or os.path.basename(os.path.dirname(url))
     track_fp.close()
     return filesize, filetype, filename
@@ -109,22 +108,29 @@ class SoundcloudUser(object):
     def commit_cache(self):
         json.dump(self.cache, open(self.cache_file, 'w'))
 
-    def get_coverart(self):
+    def get_user_info(self):
         global CONSUMER_KEY
-        key = ':'.join((self.username, 'avatar_url'))
+        key = ':'.join((self.username, 'user_info'))
         if key in self.cache:
             return self.cache[key]
 
-        image = None
         try:
-            json_url = 'http://api.soundcloud.com/users/%s.json?consumer_key=%s' % (self.username, CONSUMER_KEY)
-            user_info = json.load(util.urlopen(json_url))
-            image = user_info.get('avatar_url', None)
-            self.cache[key] = image
+            json_url = 'https://api.soundcloud.com/users/%s.json?consumer_key=%s' % (self.username, CONSUMER_KEY)
+            user_info = json.loads(util.urlopen(json_url).read().decode('utf-8'))
+            self.cache[key] = user_info
         finally:
             self.commit_cache()
 
-        return image
+        return user_info
+
+    def get_coverart(self):
+        user_info = self.get_user_info()
+        return user_info.get('avatar_url', None)
+
+    def get_user_id(self):
+        user_info = self.get_user_info()
+        return user_info.get('id', None)
+
 
     def get_tracks(self, feed):
         """Get a generator of tracks from a SC user
@@ -133,10 +139,21 @@ class SoundcloudUser(object):
         track it can find for its user."""
         global CONSUMER_KEY
         try:
-            json_url = 'http://api.soundcloud.com/users/%(user)s/%(feed)s.json?filter=downloadable&consumer_key=%(consumer_key)s&limit=200' \
-                    % { "user":self.username, "feed":feed, "consumer_key": CONSUMER_KEY }
-            tracks = (track for track in json.load(util.urlopen(json_url)) \
-                    if track['downloadable'])
+            json_url = 'https://api.soundcloud.com/users/%(user)s/%(feed)s.json?filter=downloadable&consumer_key=%(consumer_key)s&limit=200' \
+                    % { "user":self.get_user_id(), "feed":feed, "consumer_key": CONSUMER_KEY }
+            logger.debug("loading %s", json_url)
+
+            json_tracks = json.loads(util.urlopen(json_url).read().decode('utf-8'))
+            tracks = [track for track in json_tracks if track['downloadable']]
+            total_count = len(tracks) + len([track for track in json_tracks
+                                              if not track['downloadable']])
+
+            if len(tracks) == 0 and total_count > 0:
+                logger.warn("Download of all %i %s of user %s is disabled" %
+                            (total_count, feed, self.username))
+            else:
+                logger.info("%i/%i downloadable tracks for user %s %s feed" %
+                            (len(tracks), total_count, self.username, feed))
 
             for track in tracks:
                 # Prefer stream URL (MP3), fallback to download URL
@@ -152,7 +169,7 @@ class SoundcloudUser(object):
 
                 yield {
                     'title': track.get('title', track.get('permalink')) or _('Unknown track'),
-                    'link': track.get('permalink_url') or 'http://soundcloud.com/'+self.username,
+                    'link': track.get('permalink_url') or 'https://soundcloud.com/'+self.username,
                     'description': track.get('description') or _('No description available'),
                     'url': url,
                     'file_size': int(filesize),
@@ -164,7 +181,7 @@ class SoundcloudUser(object):
             self.commit_cache()
 
 class SoundcloudFeed(object):
-    URL_REGEX = re.compile('http://([a-z]+\.)?soundcloud\.com/([^/]+)$', re.I)
+    URL_REGEX = re.compile('https?://([a-z]+\.)?soundcloud\.com/([^/]+)$', re.I)
 
     @classmethod
     def handle_url(cls, url):
@@ -184,7 +201,7 @@ class SoundcloudFeed(object):
         return self.sc_user.get_coverart()
 
     def get_link(self):
-        return 'http://soundcloud.com/%s' % self.username
+        return 'https://soundcloud.com/%s' % self.username
 
     def get_description(self):
         return _('Tracks published by %s on Soundcloud.') % self.username
@@ -207,7 +224,7 @@ class SoundcloudFeed(object):
         return episodes, seen_guids
 
 class SoundcloudFavFeed(SoundcloudFeed):
-    URL_REGEX = re.compile('http://([a-z]+\.)?soundcloud\.com/([^/]+)/favorites', re.I)
+    URL_REGEX = re.compile('https?://([a-z]+\.)?soundcloud\.com/([^/]+)/favorites', re.I)
 
 
     def __init__(self, username):
@@ -217,7 +234,7 @@ class SoundcloudFavFeed(SoundcloudFeed):
         return _('%s\'s favorites on Soundcloud') % self.username
 
     def get_link(self):
-        return 'http://soundcloud.com/%s/favorites' % self.username
+        return 'https://soundcloud.com/%s/favorites' % self.username
 
     def get_description(self):
         return _('Tracks favorited by %s on Soundcloud.') % self.username
@@ -230,5 +247,5 @@ model.register_custom_handler(SoundcloudFeed)
 model.register_custom_handler(SoundcloudFavFeed)
 
 def search_for_user(query):
-    json_url = 'http://api.soundcloud.com/users.json?q=%s&consumer_key=%s' % (urllib.quote(query), CONSUMER_KEY)
-    return json.load(util.urlopen(json_url))
+    json_url = 'https://api.soundcloud.com/users.json?q=%s&consumer_key=%s' % (urllib.parse.quote(query), CONSUMER_KEY)
+    return json.loads(util.urlopen(json_url).read().decode('utf-8'))
