@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2017 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@ import shutil
 import logging
 logger = logging.getLogger(__name__)
 
+from gpodder import util
+
 EpisodeColumns = (
     'podcast_id',
     'title',
@@ -47,6 +49,7 @@ EpisodeColumns = (
     'current_position_updated',
     'last_playback',
     'payment_url',
+    'description_html',
 )
 
 PodcastColumns = (
@@ -69,7 +72,7 @@ PodcastColumns = (
     'cover_thumb',
 )
 
-CURRENT_VERSION = 6
+CURRENT_VERSION = 7
 
 
 # SQL commands to upgrade old database versions to new ones
@@ -103,6 +106,14 @@ UPGRADE_SQL = [
         (5, 6, """
         ALTER TABLE podcast ADD COLUMN cover_thumb BLOB NULL DEFAULT NULL
         """),
+
+        # Version 7: Add HTML description
+        (6, 7, """
+        ALTER TABLE episode ADD COLUMN description_html TEXT NOT NULL DEFAULT ''
+        UPDATE episode SET description_html=description WHERE is_html(description)
+        UPDATE episode SET description=remove_html_tags(description_html) WHERE is_html(description)
+        UPDATE podcast SET http_last_modified=NULL, http_etag=NULL
+        """),
 ]
 
 def initialize_database(db):
@@ -159,7 +170,8 @@ def initialize_database(db):
         current_position INTEGER NOT NULL DEFAULT 0,
         current_position_updated INTEGER NOT NULL DEFAULT 0,
         last_playback INTEGER NOT NULL DEFAULT 0,
-        payment_url TEXT NULL DEFAULT NULL
+        payment_url TEXT NULL DEFAULT NULL,
+        description_html TEXT NOT NULL DEFAULT ''
     )
     """)
 
@@ -187,6 +199,9 @@ def upgrade(db, filename):
         initialize_database(db)
         return
 
+    db.create_function('is_html', 1, util.is_html)
+    db.create_function('remove_html_tags', 1, util.remove_html_tags)
+
     version = db.execute('SELECT version FROM version').fetchone()[0]
     if version == CURRENT_VERSION:
         return
@@ -195,7 +210,7 @@ def upgrade(db, filename):
     backup = '%s_upgraded-v%d_%d' % (filename, int(version), int(time.time()))
     try:
         shutil.copy(filename, backup)
-    except Exception, e:
+    except Exception as e:
         raise Exception('Cannot create DB backup before upgrade: ' + e)
 
     db.execute("DELETE FROM version")
@@ -231,7 +246,7 @@ def convert_gpodder2_db(old_db, new_db):
     old_cur = old_db.cursor()
     columns = [x[1] for x in old_cur.execute('PRAGMA table_info(channels)')]
     for row in old_cur.execute('SELECT * FROM channels'):
-        row = dict(zip(columns, row))
+        row = dict(list(zip(columns, row)))
         values = (
                 row['id'],
                 row['override_title'] or row['title'],
@@ -250,6 +265,7 @@ def convert_gpodder2_db(old_db, new_db):
                 None,
                 0,
                 row['sync_to_devices'],
+                None,
         )
         new_db.execute("""
         INSERT INTO podcast VALUES (%s)
@@ -260,7 +276,7 @@ def convert_gpodder2_db(old_db, new_db):
     old_cur = old_db.cursor()
     columns = [x[1] for x in old_cur.execute('PRAGMA table_info(episodes)')]
     for row in old_cur.execute('SELECT * FROM episodes'):
-        row = dict(zip(columns, row))
+        row = dict(list(zip(columns, row)))
         values = (
                 row['id'],
                 row['channel_id'],
@@ -281,10 +297,18 @@ def convert_gpodder2_db(old_db, new_db):
                 row['current_position_updated'],
                 0,
                 None,
+                '',
         )
         new_db.execute("""
         INSERT INTO episode VALUES (%s)
         """ % ', '.join('?'*len(values)), values)
+        # do 6 -> 7 upgrade (description_html)
+        new_db.create_function('is_html', 1, util.is_html)
+        new_db.create_function('remove_html_tags', 1, util.remove_html_tags)
+        new_db.execute("UPDATE episode SET description_html=description WHERE is_html(description)")
+        new_db.execute("UPDATE episode SET description=remove_html_tags(description_html) WHERE is_html(description)")
+        new_db.execute("UPDATE podcast SET http_last_modified=NULL, http_etag=NULL")
+
     old_cur.close()
 
     old_db.close()
