@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2017 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,20 +30,12 @@ import os.path
 import logging
 logger = logging.getLogger(__name__)
 
-try:
-    import simplejson as json
-except ImportError:
-    import json
+import json
 
 import re
-import urllib
+import urllib.request, urllib.parse, urllib.error
 
-try:
-    # Python >= 2.6
-    from urlparse import parse_qs
-except ImportError:
-    # Python < 2.6
-    from cgi import parse_qs
+from urllib.parse import parse_qs
 
 # http://en.wikipedia.org/wiki/YouTube#Quality_and_codecs
 # format id, (preferred ids, path(?), description) # video bitrate, audio bitrate
@@ -117,7 +109,7 @@ def get_real_download_url(url, preferred_fmt_ids=None):
         def find_urls(page):
             r4 = re.search('url_encoded_fmt_stream_map=([^&]+)', page)
             if r4 is not None:
-                fmt_url_map = urllib.unquote(r4.group(1))
+                fmt_url_map = urllib.parse.unquote(r4.group(1))
                 for fmt_url_encoded in fmt_url_map.split(','):
                     video_info = parse_qs(fmt_url_encoded)
                     yield int(video_info['itag'][0]), video_info['url'][0]
@@ -212,7 +204,7 @@ def get_real_cover(url):
     def return_user_cover(url, channel):
         try:
             api_url = 'https://www.youtube.com/channel/{0}'.format(channel)
-            data = util.urlopen(api_url).read()
+            data = util.urlopen(api_url).read().decode('utf-8')
             # Look for 900x900px image first.
             m = re.search('<link rel="image_src"[^>]* href=[\'"]([^\'"]+)[\'"][^>]*>', data)
             if m is None:
