@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # Progressbar icon tester
 # Thomas Perl <thp.io/about>; 2012-02-05
 #
@@ -8,26 +8,26 @@
 import sys
 sys.path.insert(0, 'src')
 
-import gtk
+from gi.repository import Gtk
 
 from gpodder.gtkui.draw import draw_cake_pixbuf
 
 def gen(percentage):
     pixbuf = draw_cake_pixbuf(percentage)
-    return gtk.image_new_from_pixbuf(pixbuf)
+    return Gtk.Image.new_from_pixbuf(pixbuf)
 
-w = gtk.Window()
-w.connect('destroy', gtk.main_quit)
-v = gtk.VBox()
+w = Gtk.Window()
+w.connect('destroy', Gtk.main_quit)
+v = Gtk.VBox()
 w.add(v)
-for y in xrange(1):
-    h = gtk.HBox()
+for y in range(1):
+    h = Gtk.HBox()
     h.set_homogeneous(True)
     v.add(h)
     PARTS = 20
-    for x in xrange(PARTS + 1):
-        h.add(gen(float(x)/float(PARTS)))
+    for x in range(PARTS + 1):
+        h.add(gen(x/PARTS))
 w.set_default_size(400, 100)
 w.show_all()
-gtk.main()
+Gtk.main()
 
